@@ -2,10 +2,6 @@
 from typing import Any, Generator, Iterable, List, Optional, Union
 
 
-class ZeroMatched(ValueError):
-    """Exception raised when a function argument is missing."""
-
-
 class InvalidInputValue(Exception):
     """Exception raised for invalid input.
 
@@ -71,3 +67,14 @@ class MissingItems(Exception):
 
     def __str__(self) -> str:
         return self.message
+
+
+class MissingCRS(Exception):
+    """Exception raised when input GeoDataFrame is missing CRS."""
+
+    def __init__(self) -> None:
+        self.message = "The input GeoDataFrame is missing CRS."
+        super().__init__(self.message)
+
+    def __str__(self) -> str:
+        return self.message
